import texture_file_aiSS as textSS
import texture_file_aiToon as textToon
import procedural_aiToon as procToon
import procedural_aiSS as procSS
import maya.cmds as cmds
import sys


class Custom_Shader_Window(object):

    def __init__(self):

        self.window = "AR_Window"
        self.win_title = "Custom Shader"
        self.mat_title = "Material"
        self.attr_title = "Attributes"
        self.size = (400, 400)

        #  close old window is open
        if cmds.window(self.window, exists=1):
            cmds.deleteUI(self.window, window=1)

        #  create new window
        self.window = cmds.window(self.window, title=self.win_title, widthHeight=self.size)
        form = cmds.formLayout(numberOfDivisions=100)

        #  titles for materials and attributes
        mat_title = cmds.text(self.mat_title)
        attr_title = cmds.text(self.attr_title)

        self.attrs = cmds.optionMenu()
        cmds.menuItem(l='aiStandardSurface')
        cmds.menuItem(l='aiToon')
        cmds.menuItem(l='aiFlat')
        cmds.menuItem(l='Lambert')
        cmds.menuItem(l='Blinn')
        cmds.menuItem(l='Phong')
        cmds.menuItem(l='standardSurface')

        #  available attributes for the selected material (only available for procedural)
        self.attr_list = cmds.textScrollList(numberOfRows=8, allowMultiSelection=True,
                                             append=['Metalness', 'Emission Weight', 'Emission Color', 'Color A',
                                                     'Color B',
                                                     'Color C', 'Color D', 'Specular Roughness', 'Bump Value'],
                                             showIndexedItem=1, h=200, w=195, en=0)

        #  procedural and texture files to determine which script will run
        self.radio_butts = cmds.radioButtonGrp(la2=['Procedural', 'Texture Files'], nrb=2, on1=self.do_procedural,
                                               sl=2, on2=self.do_txt_f,
                                               an1='Can work on any objects. Will add procedural noise textures that can be customized by the user.',
                                               an2='Only works on objects with the same UVs. User can browse for desired texture files.')

        #  displays file path for selected image
        self.browse_field = cmds.textField(pht='Texture File Here', ann='Click "Browse" to search for texture file.',
                                           w=240)

        #  browses for files so user can select image for texture file (non-procedural)
        self.browse_butt = cmds.button(l='Browse', w=50, command=self.do_browse_butt, aop=1)

        #  button user clicks to run final code
        create_butt = cmds.button(l='Create', w=150, command=self.do_butt, aop=1)

        #  displays instructions for widgets when user hovers over
        help_txt = cmds.helpLine()

        #  determines where widgets are located relative to size of window
        self.win_layout = cmds.formLayout(form, edit=1, af=[(mat_title, 'top', 5), (mat_title, 'left', 100),
                                                            (attr_title, 'top', 5), (attr_title, 'right', 100),
                                                            (self.attrs, 'top', 50), (self.attrs, 'left', 5),
                                                            (self.attr_list, 'left', 250),
                                                            (self.attr_list, 'top', 30), (self.attr_list, 'right', 5),
                                                            (self.radio_butts, 'top', 250),
                                                            (self.radio_butts, 'left', 125),
                                                            (self.browse_field, 'bottom', 100),
                                                            (self.browse_field, 'top', 315),
                                                            (self.browse_field, 'left', 75),
                                                            (self.browse_butt, 'bottom', 98),
                                                            (self.browse_butt, 'top', 315),
                                                            (self.browse_butt, 'left', 320),
                                                            (create_butt, 'bottom', 50), (create_butt, 'left', 5),
                                                            (help_txt, 'left', 5), (help_txt, 'bottom', 20), ])

        cmds.showWindow(self.window)

    def do_flat(self):
        print('aiFlat')

    def do_toon(self):
        print('aiToon')

    def do_lambert(self):
        print('Lambert')

    def do_ai_ss(self):
        print('aiStandardSurface')

    def do_blinn(self):
        print('Blinn')

    def do_phong(self):
        print('Phong')

    def do_standard_s(self):
        print('Standard Surface')

    #  only here for testing purposes
    def do_nothing(self):
        pass

    def do_procedural(self, *args):
        print('Procedural')
        cmds.disable(self.browse_field)
        cmds.disable(self.browse_butt)
        cmds.disable(self.attr_list, v=0)

    def do_txt_f(self, *args):
        print('Texture Files')
        cmds.disable(self.browse_field, v=0)
        cmds.disable(self.browse_butt, v=0)
        cmds.disable(self.attr_list)

    def do_browse_butt(self, *args):
        basicFilter = "All Files (*.*)"
        global img_dir
        img_dir = cmds.fileDialog2(ff=basicFilter, dialogStyle=2, fm=1)
        hold_path = cmds.textField(self.browse_field, edit=1, tx=img_dir[0])
        print(img_dir[0])

    def do_butt(self, *args):
        value = cmds.radioButtonGrp(self.radio_butts, q=1, select=1)
        mat = cmds.optionMenu(self.attrs, q=1, select=1)

        #  procedural materials
        if value == 1 == mat:
            print('proc aiSS')
            procSS.procedural()
        if value == 2 == mat:
            print ('text aiToon')
            textToon.Shader_Creation(img_dir)
            # test.Shader_Creation(img_dir)
        if mat == 2 > value:
            print('proc aiToon')
            procToon.procedural()
        if value == 2 > mat:
            print('text aiSS')
            textSS.Shader_Creation(img_dir)
        if value == 1 and mat == 3:
            print('proc aiFlat')
        if value == 2 and mat == 3:
            print('text aiFlat')
        if value == 1 and mat == 4:
            print('proc lambert')
        if value == 2 and mat == 4:
            print('text lambert')
        if value == 1 and mat == 5:
            print('proc blinn')
        if value == 2 and mat == 5:
            print('text blinn')
        if value == 1 and mat == 6:
            print('proc phong')
        if value == 2 and mat == 6:
            print('text phong')
        if value == 1 and mat == 7:
            print('proc SS')
        if value == 2 and mat == 7:
            print('text ss')


myWindow = Custom_Shader_Window()
