####  works with texture files
####  NOT PROCEDURAL
####  only aiStandardSurface
####  only base color attribute

import maya.cmds as cmds


class Shader_Creation(object):

    def __init__(self, img_dir):
        #  adds attributes to shape nodes of selected objects
        selected = cmds.ls(sl=True, long=True)
        for obj in selected:
            global shape_node
            shape_node = cmds.listRelatives(obj, shapes=True)
            cmds.addAttr(shape_node[0], longName='mtoa_constant_rim_width', niceName='Rim_Width', at='float',
                         dv=0, min=0.0, max=1)
            cmds.addAttr(shape_node[0], longName='mtoa_constant_rim_color', niceName='Rim_Color', usedAsColor=True,
                         at='float3')
            cmds.addAttr(shape_node[0], longName='R', attributeType='float', parent='mtoa_constant_rim_color',
                         dv=1)
            cmds.addAttr(shape_node[0], longName='G', attributeType='float', parent='mtoa_constant_rim_color',
                         dv=1)
            cmds.addAttr(shape_node[0], longName='B', attributeType='float', parent='mtoa_constant_rim_color',
                         dv=1)
            cmds.addAttr(shape_node[0], longName='mtoa_constant_color_correct', niceName='Color_Correct',
                         usedAsColor=True,
                         at='float3')
            cmds.addAttr(shape_node[0], longName='red', attributeType='float', parent='mtoa_constant_color_correct',
                         dv=1)
            cmds.addAttr(shape_node[0], longName='green', attributeType='float', parent='mtoa_constant_color_correct',
                         dv=1)
            cmds.addAttr(shape_node[0], longName='blue', attributeType='float', parent='mtoa_constant_color_correct',
                         dv=1)

        #  creates material, OSL nodes, and makes proper connections
        cmds.shadingNode('aiStandardSurface', asShader=True)
        cmds.select(selected)
        cmds.hyperShade(assign='aiStandardSurface1')
        mat_name = cmds.rename('aiStandardSurface1', 'aiStandardSurface_' + shape_node[0] + '_SN')
        print(mat_name)
        osl_name = cmds.shadingNode('aiOslShader', n='ai_' + shape_node[0] + '_OSL', asShader=True)
        print(osl_name)
        cmds.select("aiStandardSurface1SG", allDagObjects=False, noExpand=True)
        sg_name = cmds.rename('aiStandardSurface1SG', 'aiStandardSurface_' + shape_node[0] + '_SG')
        print(sg_name)
        if cmds.objExists('null'):
            cmds.delete('null')
        cmds.polySphere(n='null')
        cmds.listRelatives('null', shapes=True)
        cmds.addAttr(ln='OSL_color_code', dt='string')
        cmds.setAttr('null.OSL_color_code', '''shader
            Velvet(
                color basecolor = 1,
                output color resultRGB = 0,
                output float resultF = 0)

            {
            color color_correct = 1;
            float rim_width = 0.2;
            color rim_color = color(1,1,1);

            getattribute("color_correct", color_correct);
            getattribute("rim_width", rim_width);
            getattribute("rim_color", rim_color);

            vector i = normalize(I);
            vector n = normalize(N);
            float  d = fabs(dot(-i, n));
            d = smoothstep(rim_width, 1.0, d);

            color base_mix = (basecolor * color_correct);
            color mixer = mix(rim_color, base_mix, d);
            resultRGB = mixer;
            resultF = d - 0.5;
            }''',
                     typ='string')
        cmds.connectAttr('null.OSL_color_code', 'ai_' + shape_node[0] + '_OSL.code')
        cmds.hide('null')
        cmds.shadingNode('file', n='color_map' + shape_node[0], asUtility=1)
        cmds.shadingNode('file', n='color_map' + shape_node[0], asUtility=1)
        cmds.setAttr('color_map' + shape_node[0] + '.ftn', img_dir[0], typ='string')

        #### compile OSL manually
        self.window = "Compile_Window"

        self.window = cmds.window(title="Compile", widthHeight=(200, 80), mxb=0, mnb=0)
        cmds.columnLayout(adjustableColumn=1)
        cmds.text(
            l='Select the OslColorCorrect node in the HyperShade and click "Compile OSL Code." Once complete, click "Done."',
            ww=1)
        cmds.button(l='Done', command=self.do_done_butt)
        cmds.setParent('..')
        cmds.showWindow(self.window)

    def do_done_butt(self, *args):
        cmds.deleteUI(self.window, window=1)
        cmds.connectAttr('ai_' + shape_node[0] + '_OSL.param_resultRGB', 'aiStandardSurface_' + shape_node[0] + '_SN.baseColor')
        cmds.connectAttr('color_map' + shape_node[0] + '.outColor', 'ai_' + shape_node[0] + '_OSL.param_basecolor')


#myClass = Shader_Creation()